# ActivityProperties

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**activity_centre_point** | [**GeoJSONCentrePoint**](GeoJSONCentrePoint.md) |  | 
**activity_name** | **str** |  | 
**activity_location_description** | **str** |  | 
**activity_reference_number** | **str** |  | 
**activity_type** | [**ActivityActivityTypeResponse**](ActivityActivityTypeResponse.md) |  | 
**activity_type_string** | **str** |  | 
**area_name** | **str** |  | 
**cancelled** | **bool** |  | 
**end_date** | **datetime** |  | 
**street_name** | **str** |  | 
**start_date** | **datetime** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

